@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: accessManager.php 5278 2012-10-11 07:40:51Z fishbone $
+ * @version    SVN: $Id: accessManager.php 6084 2013-06-06 12:58:33Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -21,10 +21,13 @@ class AccessManager extends Core
 	private $_clientId;					// クライアントID(クッキー用)
 	private $_oldSessionId;				// 古いセッションID
 	private $_accessLogSerialNo;		// アクセスログのシリアルNo
+	private $_useAutoLogin;				// 自動ログイン機能を使用するかどうか
    	const LOG_REQUEST_PARAM_MAX_LENGTH	= 1024;				// ログに保存するリクエストパラメータの最大長
 	const PASSWORD_LENGTH = 8;		// パスワード長
 	const SEND_PASSWORD_FORM = 'send_tmp_password';		// 仮パスワード送信用フォーム
 	const TMP_PASSWORD_AVAILABLE_HOURS = 24;						// 仮パスワード有効時間
+	const CF_AUTO_LOGIN = 'auto_login';			// 自動ログイン機能を使用するかどうか
+	const AUTO_LOGIN_EXPIRE_DAYS = 30;			// 自動ログインの有効期間
 	
 	/**
 	 * コンストラクタ
@@ -73,18 +76,12 @@ class AccessManager extends Core
 	 */
 	function userLoginByAccount($account, $password, $checkUser=true)
 	{
-		global $gInstanceManager;
-		global $gRequestManager;
-		
 		// 初期化
 		$retValue = false;
-		$now = date("Y/m/d H:i:s");	// 現在日時
 		
 		// アカウントが空のときはアクセス不可
 		if (empty($account)) return false;
 		
-		$accessIp = $gRequestManager->trimServerValueOf('REMOTE_ADDR');		// アクセスIP
-		
 		// ユーザ情報取得
 		if ($this->db->getLoginUserRecord($account, $row)){
 			// ******** ユーザのログインチェック             ********
@@ -112,48 +109,8 @@ class AccessManager extends Core
 			}
 			
 			if ($checkLogin){			// パスワード一致のとき
-				// ユーザチェックが必要な場合は承認済みユーザのみ許可する
-				if (($checkUser && $row['lu_user_type'] >= 0 && $row['lu_enable_login'] &&
-					$this->_isActive($row['lu_active_start_dt'], $row['lu_active_end_dt'], $now)) || // 承認済みユーザ、ログイン可能
-					!$checkUser){			// ユーザのアクセス権をチェックしない場合
-					
-					// ログインした場合はセッションIDを変更する
-					$this->setOldSessionId(session_id());		// 古いセッションIDを保存
-					session_regenerate_id(true);
-			
-					// ユーザ情報オブジェクトを作成
-					$userInfo = new UserInfo();
-					$userInfo->userId	= $row['lu_id'];		// ユーザID
-					$userInfo->account	= $row['lu_account'];	// ユーザアカウント
-					$userInfo->name		= $row['lu_name'];		// ユーザ名
-					$userInfo->userType	= $row['lu_user_type'];	// ユーザタイプ
-					$userInfo->userTypeOption = $row['lu_user_type_option'];			// ユーザタイプオプション
-					$userInfo->_recordSerial = $row['lu_serial'];	// レコードシリアル番号
-				
-					// アクセス可能ウィジェット(システム運用者の場合)
-					$userInfo->adminWidget = array();
-					if ($userInfo->userType == UserInfo::USER_TYPE_MANAGER){	// システム運用可能ユーザのとき
-						$adminWidget = trim($row['lu_admin_widget']);
-						if (!empty($adminWidget)) $userInfo->adminWidget = explode(',', $adminWidget);
-					}
-					
-					// システム運用可能ユーザの場合は、管理者キーを発行(2011/9/16 修正)
-					//if ($userInfo->isSystemAdmin()){
-					if ($userInfo->userType >= UserInfo::USER_TYPE_MANAGER){	// システム運用可能ユーザのとき
-						$adminKey = $this->createAdminKey();
-						if ($this->db->addAdminKey($adminKey, $accessIp)) $userInfo->_adminKey = $adminKey;
-					} else {
-						$userInfo->_adminKey = '';
-					}
-				
-					// インスタンスマネージャーとセッションに保存
-					$gInstanceManager->setUserInfo($userInfo);
-					$gRequestManager->setSessionValueWithSerialize(M3_SESSION_USER_INFO, $userInfo);
-				
-					// ログインのログを残す
-					$this->db->updateLoginLog($userInfo->userId, $this->_accessLogSerialNo);
-					$retValue = true;
-				}
+				// ユーザ情報を読み込み
+				$retValue = $this->_loadUserInfo($row, $checkUser);
 			}
 		}
 		// ログインのログを残す
@@ -171,6 +128,243 @@ class AccessManager extends Core
 		}
 		return $retValue;
 	}
+	/**
+	 * ユーザ情報を読み込み
+	 *
+	 * @param array $row		ユーザのログインユーザ情報レコード
+	 * @param bool $checkUser	ユーザのアクセス権のチェックを行うかどうか
+	 * @return bool   			true=成功、false=失敗
+	 */
+	function _loadUserInfo($row, $checkUser = true)
+	{
+		global $gInstanceManager;
+		global $gRequestManager;
+		
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$accessIp = $gRequestManager->trimServerValueOf('REMOTE_ADDR');		// アクセスIP
+				
+		// ユーザチェックが必要な場合は承認済みユーザのみ許可する
+		if (($checkUser && $row['lu_user_type'] >= 0 && $row['lu_enable_login'] &&
+			$this->_isActive($row['lu_active_start_dt'], $row['lu_active_end_dt'], $now)) || // 承認済みユーザ、ログイン可能
+			!$checkUser){			// ユーザのアクセス権をチェックしない場合
+			
+			// ログインした場合はセッションIDを変更する
+			$this->setOldSessionId(session_id());		// 古いセッションIDを保存
+			session_regenerate_id(true);
+	
+			// ユーザ情報オブジェクトを作成
+			$userInfo = new UserInfo();
+			$userInfo->userId	= $row['lu_id'];		// ユーザID
+			$userInfo->account	= $row['lu_account'];	// ユーザアカウント
+			$userInfo->name		= $row['lu_name'];		// ユーザ名
+			$userInfo->email	= $row['lu_email'];		// Eメール
+			$userInfo->userType	= $row['lu_user_type'];	// ユーザタイプ
+			$userInfo->userTypeOption = $row['lu_user_type_option'];			// ユーザタイプオプション
+			$userInfo->_recordSerial = $row['lu_serial'];	// レコードシリアル番号
+		
+			// アクセス可能ウィジェット(システム運用者の場合)
+			$userInfo->adminWidget = array();
+			if ($userInfo->userType == UserInfo::USER_TYPE_MANAGER){	// システム運用可能ユーザのとき
+				$adminWidget = trim($row['lu_admin_widget']);
+				if (!empty($adminWidget)) $userInfo->adminWidget = explode(',', $adminWidget);
+			}
+			
+			// システム運用可能ユーザの場合は、管理者キーを発行(2011/9/16 修正)
+			if ($userInfo->userType >= UserInfo::USER_TYPE_MANAGER){	// システム運用可能ユーザのとき
+				$adminKey = $this->createAdminKey();
+				if ($this->db->addAdminKey($adminKey, $accessIp)) $userInfo->_adminKey = $adminKey;
+			} else {
+				$userInfo->_adminKey = '';
+			}
+		
+			// インスタンスマネージャーとセッションに保存
+			$gInstanceManager->setUserInfo($userInfo);
+			$gRequestManager->setSessionValueWithSerialize(M3_SESSION_USER_INFO, $userInfo);
+		
+			// ログインのログを残す
+			$this->db->updateLoginLog($userInfo->userId, $this->_accessLogSerialNo);
+			return true;
+		} else {
+			return false;
+		}
+	}
+	/**
+	 * 自動ログイン開始処理
+	 *
+	 * @return bool   				true=ログイン成功、false=ログイン不可
+	 */
+	function startAutoLogin()
+	{
+		global $gSystemManager;
+		global $gRequestManager;
+		
+		// 自動ログイン機能を使用するかどうか
+		$value = $gSystemManager->getSystemConfig(self::CF_AUTO_LOGIN);
+		$this->_useAutoLogin = isset($value) ? $value : '0';
+		if (!$this->_useAutoLogin) return false;
+		
+		// ログイン中でない場合のみ自動ログイン処理を行う
+		$userId = $this->gEnv->getCurrentUserId();
+		if ($userId > 0) return false;
+
+		// 自動ログイン処理。自動ログイン情報がある場合は自動ログインクッキーも存在する
+		$loginKey = $gRequestManager->getCookieValue(M3_COOKIE_AUTO_LOGIN);		// 自動ログインキー
+		$clientId = $this->getClientId();		// クライアントID
+		if (empty($loginKey) || empty($clientId)) return false;			// 空の場合は問題なし
+		$ret = $this->db->getAutoLogin($loginKey, $clientId, $row);
+		if (!$ret){		// 自動ログイン情報がない場合は終了
+			// 自動ログイン情報を削除
+			$this->_removeAutoLogin($loginKey);
+			
+			// ユーザエラーログを残す
+			$errMsg = '不正な自動ログインを検出しました。ログインキー: ' . $loginKey;
+			$msgDetail = 'クライアントID=' . $clientId;
+			$this->gOpeLog->writeUserError(__METHOD__, $errMsg, 2310, $msgDetail);
+			return false;
+		}
+		// 自動ログインの有効期間をチェック
+		$expireDt = $row['ag_expire_dt'];
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		if ($expireDt == $this->gEnv->getInitValueOfTimestamp() || strtotime($expireDt) < strtotime($now)){		// 期限切れのとき
+			// 自動ログイン情報を削除
+			$this->_removeAutoLogin($loginKey);
+			return false;
+		}
+
+		// ユーザ情報を取得
+		$ret = $this->db->getLoginUserRecordById($row['ag_user_id'], $userInfoRow);
+		if (!$ret){
+			// 自動ログイン情報を削除
+			$this->_removeAutoLogin($loginKey);
+			
+			$errMsg = '自動ログインエラー(要因=ユーザ情報取得失敗)';
+			$msgDetail = 'ユーザID=' . $row['ag_user_id'];
+			$this->gOpeLog->writeError(__METHOD__, $errMsg, 1100, $msgDetail);
+			return false;
+		}
+		
+		// ユーザレベルをチェック。システム運用可能ユーザは自動ログイン不可。
+		// アクセスパスをチェック?
+		if ($userInfoRow['lu_user_type'] >= UserInfo::USER_TYPE_MANAGER) return false;	// システム運用可能ユーザのとき
+		
+		// ユーザ情報を読み込む
+		$ret = $this->_loadUserInfo($userInfoRow);
+		$userId = $userInfoRow['lu_id'];		// ユーザID再取得
+		$account = $userInfoRow['lu_account'];
+		if ($ret){// ログイン成功
+			// ユーザログインログを残す
+			$errMsg = 'ユーザが自動ログインしました。アカウント: ' . $account;
+			$msgDetail = 'ログインキー=' . $loginKey . ', クライアントID=' . $clientId;
+			$this->gOpeLog->writeUserInfo(__METHOD__, $errMsg, 2302/*自動ログイン*/, $msgDetail, 'account=' . $account/*検索補助データ*/);
+		} else {
+			// 自動ログイン情報を削除
+			$this->_removeAutoLogin($loginKey);
+			
+			// ユーザエラーログを残す
+			$errMsg = 'ユーザが自動ログインに失敗しました。アカウント: ' . $account;
+			$msgDetail = 'ログインキー=' . $loginKey . ', クライアントID=' . $clientId;
+			$this->gOpeLog->writeUserError(__METHOD__, $errMsg, 2310, $msgDetail, 'account=' . $account/*検索補助データ*/);
+			return false;
+		}
+		// 新規のログインキーを作成
+		$newLoginKey = md5($account . $clientId . time());
+		$ret = $this->_createAutoLogin($newLoginKey, $userId, $clientId);
+		if (!$ret){
+			$errMsg = '自動ログインエラー(要因=自動ログイン情報作成失敗)';
+			$msgDetail = 'ログインキー=' . $newLoginKey . ',ユーザID=' . $userId . ',クライアントID=' . $clientId;
+			$this->gOpeLog->writeError(__METHOD__, $errMsg, 1100, $msgDetail);
+		}
+		return true;
+	}
+	/**
+	 * 自動ログイン終了処理
+	 *
+	 * @return bool   				true=成功、false=失敗
+	 */
+	function endAutoLogin()
+	{
+		if (!$this->_useAutoLogin) return;
+	}
+	/**
+	 * 自動ログイン処理
+	 *
+	 * @param int $userId			ユーザID
+	 * @param bool $isAutoLogin		true=自動ログイン開始、false=自動ログイン終了
+	 * @return bool   				true=自動ログイン完了、false=自動ログイン失敗
+	 */
+	function userAutoLogin($userId, $isAutoLogin)
+	{
+		// 自動ログイン行わない場合は終了
+		if (!$this->_useAutoLogin) return false;
+		
+		$clientId = $this->getClientId();		// クライアントID
+
+		if ($isAutoLogin){
+			// 引数エラーチェック
+			if ($userId <= 0) return false;
+			if (empty($clientId)) return false;
+		
+			// ユーザ情報取得
+			$userInfo = $this->gEnv->getCurrentUserInfo();
+
+			// ユーザレベルをチェック。システム運用可能ユーザは自動ログイン不可。
+			if ($userInfo->userType >= UserInfo::USER_TYPE_MANAGER) return false;	// システム運用可能ユーザのとき
+			
+			// 新規のログインキーを作成
+			$newLoginKey = md5($userInfo->account . $clientId . time());
+			$ret = $this->_createAutoLogin($newLoginKey, $userId, $clientId);
+			if (!$ret){
+				$errMsg = '自動ログインエラー(要因=自動ログイン情報作成失敗)';
+				$msgDetail = 'ログインキー=' . $newLoginKey . ',ユーザID=' . $userId . ',クライアントID=' . $clientId;
+				$this->gOpeLog->writeError(__METHOD__, $errMsg, 1100, $msgDetail);
+			}
+		} else {
+			// クッキー削除は必ず行うため引数エラーチェックはしない
+			// 自動ログイン情報を削除
+			$loginKey = $this->db->getAutoLoginKey($userId, $clientId);
+			$ret = $this->_removeAutoLogin($loginKey);
+		}
+		return $ret;
+	}
+	/**
+	 * 自動ログイン情報作成
+	 *
+	 * @param string $loginKey	ログインキー
+	 * @param int    $userId	ユーザID
+	 * @param string $clientId	クライアントID
+	 * @return bool   			true=成功、false=失敗
+	 */
+	function _createAutoLogin($loginKey, $userId, $clientId)
+	{
+		global $gRequestManager;
+		
+		// クッキーを作成
+		//$gRequestManager->setCookieValue(M3_COOKIE_AUTO_LOGIN, '', -1);		// 一旦削除
+		$gRequestManager->setCookieValue(M3_COOKIE_AUTO_LOGIN, $loginKey, self::AUTO_LOGIN_EXPIRE_DAYS);
+		
+		// 自動ログイン情報を更新
+		$accessPath = $this->gEnv->getAccessPath();
+		$expireDt = date("Y/m/d H:i:s", strtotime(self::AUTO_LOGIN_EXPIRE_DAYS . ' day'));
+		$ret = $this->db->updateAutoLogin($userId, $loginKey, $clientId, $accessPath, $expireDt);
+		return $ret;
+	}
+	/**
+	 * 自動ログイン情報削除
+	 *
+	 * @param string $loginKey	ログインキー
+	 * @return bool   			true=成功、false=失敗
+	 */
+	function _removeAutoLogin($loginKey)
+	{
+		global $gRequestManager;
+		
+		// クッキーを削除
+		$gRequestManager->setCookieValue(M3_COOKIE_AUTO_LOGIN, '', -1);
+		
+		// 自動ログイン情報削除
+		$ret = $this->db->delAutoLogin($loginKey);
+		return $ret;
+	}
 	/**
 	 * 期間から公開可能かチェック
 	 *
@@ -204,6 +398,9 @@ class AccessManager extends Core
 		// ユーザ情報取得
 		$userInfo = $this->gEnv->getCurrentUserInfo();
 		
+		// ##### 自動ログイン情報を削除 #####
+		$this->userAutoLogin($userInfo->userId, false/*自動ログイン情報削除*/);
+		
 		// ログアウトログを残す
 		if (!is_null($userInfo)){
 			$this->gOpeLog->writeUserInfo(__METHOD__, 'ユーザがログアウトしました。アカウント: ' . $userInfo->account, 2301,
