@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: cacheManager.php 3039 2010-04-16 08:56:31Z fishbone $
+ * @version    SVN: $Id: cacheManager.php 3456 2010-08-06 04:55:15Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -62,8 +62,8 @@ class CacheManager extends Core
 			M3_REQUEST_PARAM_CONTENT_ID_SHORT,				// コンテンツID(略式)
 			M3_REQUEST_PARAM_PRODUCT_ID,		// 製品ID
 			M3_REQUEST_PARAM_PRODUCT_ID_SHORT,				// 製品ID(略式)
-			M3_REQUEST_PARAM_BLOG_ID,			// ブログ記事ID
-			M3_REQUEST_PARAM_BLOG_ID_SHORT,				// ブログ記事ID(略式)
+			M3_REQUEST_PARAM_BLOG_ENTRY_ID,			// ブログ記事ID
+			M3_REQUEST_PARAM_BLOG_ENTRY_ID_SHORT,				// ブログ記事ID(略式)
 			M3_REQUEST_PARAM_BBS_ID,		// 掲示板投稿記事ID
 			M3_REQUEST_PARAM_BBS_ID_SHORT				// 掲示板投稿記事ID(略式)
 		);
