@@ -13,7 +13,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: launchManager.php 3318 2010-06-30 06:49:38Z fishbone $
+ * @version    SVN: $Id: launchManager.php 4964 2012-06-13 12:22:28Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -206,12 +206,17 @@ class LaunchManager extends Core
 	 *
 	 * @param string $task		タスク名
 	 * @param bool $isAdmin		管理者機能(adminディレクトリ以下)かどうか
+	 * @param string $defaultWidgetId	カレントウィジェットの実行クラスが取得できない場合のデフォルトウィジェットID
+	 * @return なし
 	 */
-	function goSubWidget($task, $isAdmin = false)
+	function goSubWidget($task, $isAdmin = false, $defaultWidgetId = '')
 	{
 		global $gEnvManager;
 		global $gRequestManager;
 		
+		// ウィジェットの種別を設定
+		$gEnvManager->setIsSubWidget(true);			// サブウィジェットで起動
+		
 		// コンテナクラス名作成
 		// フォーマット: [ウィジェットID][タスク名]WidgetContainer
 		$widgetId = $gEnvManager->getCurrentWidgetId();// ウィジェットID
@@ -222,23 +227,48 @@ class LaunchManager extends Core
 		// コンテナクラス名修正
 		$containerClass = str_replace('/', '_', $containerClass);
 		
-		// ウィジェットの種別を設定
-		$gEnvManager->setIsSubWidget(true);			// サブウィジェットで起動
-		
 		// コンテナクラスが既にロードされているときはエラー
 		if (class_exists($containerClass)){
 			echo 'class redefined error2: ' . $containerClass;
 		} else {
 			// コンテナクラスファイル取り込み
-			$containerPath = $gEnvManager->getCurrentWidgetContainerPath() . '/' . $containerClass . '.php';
+			$containerPath = $gEnvManager->getCurrentWidgetContainerPath() . '/' . $containerClass . '.php';	// カレントウィジェットのコンテナクラス
 			if (file_exists($containerPath)){
 				require_once($containerPath);
+				
+				// コンテナクラスを起動
+				$widgetContainer = new $containerClass();
+				$widgetContainer->process($gRequestManager);
 			} else {
-				echo 'file not found error: ' . $containerPath;
+				if (empty($defaultWidgetId)){
+					echo 'file not found error: ' . $containerPath;
+				} else {		// デフォルトのウィジェットIDが指定されている場合はデフォルトウィジェットIDで実行
+					// コンテナクラス名作成
+					$containerClass = '';
+					if ($isAdmin) $containerClass .= 'admin_';
+					$containerClass .= $defaultWidgetId . ucfirst($task) . 'WidgetContainer';
+
+					// コンテナクラス名修正
+					$containerClass = str_replace('/', '_', $containerClass);
+					
+					// コンテナクラスが既にロードされているときはエラー
+					if (class_exists($containerClass)){
+						echo 'class redefined error3: ' . $containerClass;
+					} else {
+						// コンテナクラスファイル取り込み
+						$containerPath = $gEnvManager->getWidgetsPath() . '/' . $defaultWidgetId . '/include/container/' . $containerClass . '.php';
+						if (file_exists($containerPath)){
+							require_once($containerPath);
+				
+							// コンテナクラスを起動
+							$widgetContainer = new $containerClass();
+							$widgetContainer->process($gRequestManager);
+						} else {
+							echo 'file not found error: ' . $containerPath;
+						}
+					}
+				}
 			}
-			// コンテナクラスを起動
-			$widgetContainer = new $containerClass();
-			$widgetContainer->process($gRequestManager);
 		}
 	}
 	/**
