@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2013 Magic3 Project.
+ * @copyright  Copyright 2006-2014 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConditionBaseWidgetContainer.php 5802 2013-03-07 06:14:29Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -19,6 +19,7 @@ require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 class admin_mainConditionBaseWidgetContainer extends admin_mainBaseWidgetContainer
 {
 	protected $_mainDb;
+	protected $_openBy;				// ウィンドウオープンタイプ
 	const TASK_BASE_NAME = '運用状況';			// 機能のベース名
 	const TASK_CALC		= 'analyzecalc';		// 集計
 	const TASK_GRAPH	= 'analyzegraph';		// グラフ表示
@@ -28,7 +29,9 @@ class admin_mainConditionBaseWidgetContainer extends admin_mainBaseWidgetContain
 	const TASK_ACCESSLOG_DETAIL	= 'accesslog_detail';		// アクセスログ詳細
 	const TASK_SEARCHWORDLOG	= 'searchwordlog';				// 検索語ログ一覧
 	const TASK_SEARCHWORDLOG_DETAIL	= 'searchwordlog_detail';		// 検索語ログ詳細
+	const TASK_AWSTATS		= 'awstats';		// Awstats表示
 	const DEFAULT_TOP_PAGE = 'accesslog';		// デフォルトのトップ画面
+	const CF_AWSTATS_DATA_PATH = 'awstats_data_path';		// Awstatsデータパス
 	
 	/**
 	 * コンストラクタ
@@ -40,6 +43,20 @@ class admin_mainConditionBaseWidgetContainer extends admin_mainBaseWidgetContain
 		
 		$this->_mainDb = new admin_mainDb();
 	}
+	/**
+	 * テンプレートに前処理
+	 *
+	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
+	 * @return								なし
+	 */
+	function _preAssign($request, &$param)
+	{
+		$this->_openBy = $request->trimValueOf(M3_REQUEST_PARAM_OPEN_BY);		// ウィンドウオープンタイプ
+		if (!empty($this->_openBy)) $this->addOptionUrlParam(M3_REQUEST_PARAM_OPEN_BY, $this->_openBy);
+	}
 	/**
 	 * テンプレートにデータ埋め込む
 	 *
@@ -51,6 +68,8 @@ class admin_mainConditionBaseWidgetContainer extends admin_mainBaseWidgetContain
 	 */
 	function _postAssign($request, &$param)
 	{
+		if ($this->_openBy == 'simple') return;			// シンプルウィンドウのときはメニューを表示しない
+		
 		// 表示画面を決定
 		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
 		if (empty($task)) $task = self::DEFAULT_TOP_PAGE;
@@ -69,6 +88,9 @@ class admin_mainConditionBaseWidgetContainer extends admin_mainBaseWidgetContain
 			case self::TASK_SEARCHWORDLOG_DETAIL:		// 検索語ログ詳細
 				$linkList = ' &gt;&gt; ログ &gt;&gt; 検索キーワード';
 				break;
+			case self::TASK_AWSTATS:		// Awstats表示
+				$linkList = ' &gt;&gt; アクセス数 &gt;&gt; Awstats';
+				break;
 			case self::TASK_GRAPH:	// グラフ表示
 				$linkList = ' &gt;&gt; アクセス数 &gt;&gt; グラフ表示';
 				break;
@@ -89,7 +111,8 @@ class admin_mainConditionBaseWidgetContainer extends admin_mainBaseWidgetContain
 			$task == self::TASK_OPELOG ||			// 運用ログ一覧
 			$task == self::TASK_OPELOG_DETAIL ||		// 運用ログ詳細
 			$task == self::TASK_SEARCHWORDLOG ||				// 検索語ログ一覧
-			$task == self::TASK_SEARCHWORDLOG_DETAIL){		// 検索語ログ詳細
+			$task == self::TASK_SEARCHWORDLOG_DETAIL ||	// 検索語ログ詳細
+			$task == self::TASK_AWSTATS){		// Awstats表示
 			$current = 'id="current"';
 		}
 		// ヘルプを作成
@@ -121,7 +144,8 @@ class admin_mainConditionBaseWidgetContainer extends admin_mainBaseWidgetContain
 			$task == self::TASK_OPELOG ||			// 運用ログ一覧
 			$task == self::TASK_OPELOG_DETAIL ||		// 運用ログ詳細
 			$task == self::TASK_SEARCHWORDLOG ||				// 検索語ログ一覧
-			$task == self::TASK_SEARCHWORDLOG_DETAIL){		// 検索語ログ詳細
+			$task == self::TASK_SEARCHWORDLOG_DETAIL ||		// 検索語ログ詳細
+			$task == self::TASK_AWSTATS){		// Awstats表示
 			
 			// ### アクセスログ ###
 			$current = '';
@@ -146,6 +170,19 @@ class admin_mainConditionBaseWidgetContainer extends admin_mainBaseWidgetContain
 			// ヘルプを作成
 			$helpText = $this->gInstance->getHelpManager()->getHelpText(self::TASK_SEARCHWORDLOG);
 			$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span ' . $helpText . '>検索キーワード</span></a></li>' . M3_NL;
+			
+			// ### Awstats ###
+			$current = '';
+			$link = $this->gEnv->getDefaultAdminUrl() . '?' . 'task=' . self::TASK_AWSTATS;			// Awstats
+			if ($task == self::TASK_AWSTATS) $current = 'id="current"';
+			// ヘルプを作成
+			$helpText = $this->gInstance->getHelpManager()->getHelpText(self::TASK_AWSTATS);
+			$isAwstats = $this->isExistsAwstats();
+			if ($isAwstats){		// Awstatsが使用可能な場合
+				$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span ' . $helpText . '>Awstats</span></a></li>' . M3_NL;
+			} else {
+				$menuText .= '<li ' . $current . '><a href="javascript:void(0);"><span ' . $helpText . '>Awstats</span></a></li>' . M3_NL;
+			}
 		} else if ($task == self::TASK_GRAPH ||	// グラフ表示
 					$task == self::TASK_CALC){		// 集計
 
@@ -175,5 +212,45 @@ class admin_mainConditionBaseWidgetContainer extends admin_mainBaseWidgetContain
 		$outputText .= '<table width="90%"><tr><td>' . $linkList . $menuText . '</td></tr></table>' . M3_NL;
 		$this->tmpl->addVar("_widget", "menu_items", $outputText);
 	}
+	/**
+	 * Awstatsの作成データが参照できるかどうか
+	 *
+	 * @return bool		true=参照可、false=参照不可
+	 */
+	function isExistsAwstats()
+	{
+		$awstatsDataPath = $this->getAwstatsPath();
+		if (is_dir($awstatsDataPath)){
+			return true;
+		} else {
+			return false;
+		}
+	}
+	/**
+	 * Awstatsの作成データのパスを取得
+	 *
+	 * @return string		パス
+	 */
+	function getAwstatsPath()
+	{
+		$path = $this->gSystem->getSystemConfig(self::CF_AWSTATS_DATA_PATH);
+		if (empty($path)) return '';
+		
+		$awstatsDataPath = rel2abs($path, $this->gEnv->getSystemRootPath());
+		return $awstatsDataPath;
+	}
+	/**
+	 * Awstatsの作成データのURLを取得
+	 *
+	 * @return string		URL
+	 */
+	function getAwstatsUrl()
+	{
+		$path = $this->gSystem->getSystemConfig(self::CF_AWSTATS_DATA_PATH);
+		if (empty($path)) return '';
+		
+		$awstatsDataPath = rel2abs($path, $this->gEnv->getRootUrl());
+		return $awstatsDataPath;
+	}
 }
 ?>
