@@ -17,6 +17,7 @@ require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWid
 require_once($gEnvManager->getLibPath() .	'/tcpdf/config/lang/jpn.php');
 require_once($gEnvManager->getLibPath() .	'/tcpdf/tcpdf.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
+require_once($gEnvManager->getLibPath() .	'/gitRepo.php');
 
 class admin_mainTestWidgetContainer extends admin_mainBaseWidgetContainer
 {
@@ -78,6 +79,36 @@ class admin_mainTestWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
+		echo $this->_realValue('false');
+		echo $this->_realValue('true');
+		echo $this->_realValue('\'true\'');
+//		echo intval((boolean)"false").'---';
+//		echo intval("true").'---';
+//		echo intval("false").'---';
+//		echo intval((boolean)"true").'---';
+/*		$ret = $repo->createZipArchive('/widgets/blog_search_box', $this->gEnv->getIncludePath() . DIRECTORY_SEPARATOR . 'widgets_update' . DIRECTORY_SEPARATOR . 'blog_search_box.zip');
+		if (!$ret){
+			$resCode = $repo->getResponseCode();
+			if ($resCode == 403){
+				echo '接続回数の上限を超えました。しばらく待ってから再度接続してください。';
+			} else {
+				echo 'GitHubへの接続に失敗しました。';
+			}
+		}*/
+	}
+    function _realValue($value)
+	{
+		$value = trim($value);
+		if (strStartsWith($value, '\'') && strEndsWith($value, '\'')){			// 文字列
+			$value = trim($value, '\'');
+		} else {
+			if (strcasecmp($value, 'true') == 0){
+				$value = 1;
+			} else if (strcasecmp($value, 'false') == 0){
+				$value = 0;
+			}
+		}
+		return $value;
 	}
 }
 ?>
