@@ -16,6 +16,7 @@
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 require_once($gEnvManager->getLibPath()				. '/pcl/pclzip.lib.php' );
+require_once($gEnvManager->getLibPath() .	'/gitRepo.php');
 require_once($gEnvManager->getCurrentWidgetContainerPath()		. '/admin_mainDef.php');			// 定義クラス
 
 class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
@@ -31,6 +32,11 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 	const CSS_FILE_EXT = 'css';		// cssファイル拡張子
 	const PHP_FILE_EXT = 'php';		// phpファイル拡張子
 	const NOT_FOUND_WIDGET_ICON_FILE = '/images/system/notfound32.png';		// ウィジェットが見つからないアイコン
+	const DOWNLOAD_ZIP_ICON_FILE = '/images/system/download_zip32.png';		// Zipダウンロード用アイコン
+	const UPLOAD_ICON_FILE = '/images/system/upload32.png';		// ウィジェットアップロード用アイコン
+	const RELOAD_ICON_FILE = '/images/system/reload32.png';		// 再読み込み用アイコン
+	const AREA_OPEN_ICON_FILE = '/images/system/area_open32.png';		// 拡張領域表示アイコン
+	const NEW_INFO_URL = 'https://raw.githubusercontent.com/magic3org/magic3/master/include/sql/update_widgets.sql';		// ウィジェットの最新情報ファイル
 	
 	/**
 	 * コンストラクタ
@@ -93,7 +99,8 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 		$widgetId = $request->trimValueOf('widget');		// 処理対象のウィジェット
 		$this->widgetType = $request->trimValueOf('item_type');// 現在のウィジェットタイプ
 		if ($this->widgetType == '') $this->widgetType = '0';		// デフォルトはPC用ウィジェット
-		$this->showDetail = ($request->trimValueOf('item_show_detail') == 'on') ? 1 : 0;		// 詳細表示するかどうか
+//		$this->showDetail = ($request->trimValueOf('item_show_detail') == 'on') ? 1 : 0;		// 詳細表示するかどうか
+		$this->showDetail = $request->trimValueOf('item_show_detail');
 				
 		if ($act == 'readnew'){		// ウィジェット再読み込みのとき
 			$addWidgetCount = 0;
@@ -121,6 +128,10 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 						if (strncmp($file, '.', 1) != 0 && $file != '..' && is_dir($filePath)
 								&& strncmp($file, '_', 1) != 0		// 「_」で始まる名前のディレクトリは読み込まない
 								&& strlen($file) > 1){		// 1文字のディレクトリは読み込まない
+							// index.phpファイルがあるかどうか確認
+							$indexFile = $filePath . DIRECTORY_SEPARATOR . M3_FILENAME_INDEX;
+							if (!file_exists($indexFile)) continue;
+							
 							// ウィジェットIDを作成
 							switch ($this->widgetType){
 								case '0':		// PC用テンプレート
@@ -169,16 +180,17 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 			$this->setMsg(self::MSG_GUIDANCE, $msg);
 		} else if ($act == 'updateline'){		// 行更新のとき
 			// 変更可能値
-			$updateName = $request->trimValueOf('item' . $selectedItemNo . '_name');				// 名前
+//			$updateName = $request->trimValueOf('item' . $selectedItemNo . '_name');				// 名前
 			$updateAvailable = ($request->trimValueOf('item' . $selectedItemNo . '_available') == 'on') ? 1 : 0;		// 利用可能かどうか
 			$updateActive = ($request->trimValueOf('item' . $selectedItemNo . '_active') == 'on') ? 1 : 0;		// ウィジェット実行可能かどうか
 			
-			$ret = $this->db->updateWidget($serial, $updateName, $updateAvailable, $updateActive);
+			$updateParams = array();
+			$updateParams['wd_available'] = $updateAvailable;
+			$updateParams['wd_active'] = $updateActive;
+			$ret = $this->db->updateWidget($serial, $updateParams);
 			if ($ret){		// データ更新成功のとき
-				//$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 				$this->setMsg(self::MSG_GUIDANCE, $this->_('Line updated.'));		// データを更新しました
 			} else {
-				//$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
 				$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in updating line.'));	// データ更新に失敗しました
 			}
 		} else if ($act == 'deleteline'){		// ウィジェット削除のとき
@@ -460,12 +472,97 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 				unlink($tmpFile);
 			}
 		} else if ($act == 'changedetail'){		// 詳細表示の変更のとき
-			// 画面設定値を更新
-			$this->gDisp->setAdminConfig(admin_mainDef::CFG_SHOW_WIDGET_DETAIL, strval($this->showDetail));
+			// 詳細表示の状態を変更
+			if ($this->showDetail){
+				$this->showDetail = 0;
+			} else {
+				$this->showDetail = 1;
+			}
+		} else if ($act == 'newinfo'){		// ウィジェットの最新情報を取得
+			// ウィジェットの最新情報ファイルを取得
+			$infoSrc = file_get_contents(self::NEW_INFO_URL);
+
+			// ウィジェットIDとバージョン番号を取得して登録
+			$exp = '/^\(\'([a-zA-Z0-9_\-\/]+)\'.*\'([0-9\.]+[a-z]*)\'/m';			// バージョン番号の最後の「b」(ベータ版)等は許可
+	        $dest = preg_replace_callback($exp, array($this, '_update_widget_info_callback'), $infoSrc);
+			
+			$this->setMsg(self::MSG_GUIDANCE, $this->_('Latest widget information gotten.'));		// 最新のウィジェット情報を取得しました
+		} else if ($act == 'updatewidget'){		// ウィジェットの更新
+			// ### 最新のバージョン番号をチェック ###
+			$canUpdate = false;			// 更新可能かどうか
+			
+			// 現在のバージョン取得
+			$ret = $this->_db->getWidgetInfo($widgetId, $row);
+			if ($ret) $version = $row['wd_version'];		// ウィジェットのバージョン
+											
+			// ウィジェットの最新情報ファイルを取得
+			$infoSrc = file_get_contents(self::NEW_INFO_URL);
+
+			// ウィジェットIDとバージョン番号を取得して登録
+			$exp = '/^\(\'' . preg_quote($widgetId, '/') . '\'.*\'([0-9\.]+[a-z]*)\'/m';			// バージョン番号の最後の「b」(ベータ版)等は許可
+			if (preg_match($exp, $infoSrc, $matches)){
+				$latestVersion = $matches[1];
+				
+				if (!empty($version) && !empty($latestVersion) && version_compare($version, $latestVersion) == -1) $canUpdate = true;		// 最新バージョンが現在のバージョンよりも上の場合
+			}
+			if ($canUpdate){
+				// GitHubからソースコードを取得
+				$zipFilePath = $this->gEnv->getIncludePath() . '/widgets_update/' . $widgetId . '#' . date('Ymd') . '.zip';
+				$repo = new GitRepo('magic3org', 'magic3');
+				$ret = $repo->createZipArchive('/widgets/' . $widgetId, $zipFilePath);
+				if ($ret){		// Zipファイル作成完了のとき
+					// 既存ウィジェットのバックアップ
+					$status = false;
+					$widgetDir = $this->gEnv->getWidgetsPath() . '/' . $widgetId;		// ウィジェットのディレクトリ
+					$backupZipFilePath = $this->gEnv->getIncludePath() . '/widgets_update/' . $widgetId . '.zip';
+					$zipFile = new PclZip($backupZipFilePath);
+					$ret = $zipFile->create($widgetDir, PCLZIP_OPT_REMOVE_PATH, dirname($widgetDir));
+					if ($ret){
+						// 作業ディレクトリを作成
+						$tmpDir = $this->gEnv->getTempDirBySession();		// セッション単位の作業ディレクトリを取得
+						if (file_exists($tmpDir)) rmDirectory($tmpDir);		// 存在する場合は一旦削除
+							
+						// ダウンロードしたウィジェットと入れ替え
+						$zipFile = new PclZip($zipFilePath);
+						$ret = $zipFile->extract(PCLZIP_OPT_PATH, $tmpDir);
+						if ($ret){
+							$ret = rmDirectory($widgetDir);
+							if ($ret) $ret = mvDirectory($tmpDir . '/' . basename($widgetId), $widgetDir);
+							if ($ret){		// 完了の場合はバージョン情報を更新
+								// DBに登録するウィジェット情報を取得
+								$exp = '/INSERT\sINTO\s_widgets[\s]*?\(([^\n]*?)\)[\s]*?VALUES[\s]*?\((\'' . preg_quote($widgetId, '/') . '\'[^\n]*?)\);/s';
+								if (preg_match($exp, $infoSrc, $matches)){
+									// パラメータ解析
+									$updateParams = $this->_parseSqlQuery($matches[1], $matches[2]);
+									if (count($updateParams) > 0){
+										$ret = $this->db->updateWidget($row['wd_serial'], $updateParams);
+										if ($ret) $status = true;		// ウィジェット更新完了
+									}
+								}
+							}
+						}
+					}
+					if ($status){
+						$msg = $this->_('Widget updated successfully.');		// ウィジェットの更新が完了しました。
+						$this->setGuidanceMsg($msg);
+					} else {
+						$msg = $this->_('Failed in updating widget.');		// ウィジェットの更新に失敗しました
+						$this->setAppErrorMsg($msg);
+					}
+				} else {		// Zipファイル作成失敗のとき
+					$resCode = $repo->getResponseCode();
+					if ($resCode == 403){
+						$msg = $this->_('Connection count is over the limit. Wait a minute, connect again.');		// ウィジェットの更新に失敗しました
+					} else {
+						$msg = $this->_('Failed in connecting to GitHub.');		// GitHubへの接続に失敗しました
+					}
+					$this->setAppErrorMsg($msg);
+				}
+			} else {
+				$msg = $this->_('The widget is already the latest version.');		// ウィジェットはすでに最新バージョンです
+				$this->setAppErrorMsg($msg);
+			}
 		}
-		// 詳細設定状況を再取得
-		$this->showDetail = intval($this->gDisp->getAdminConfig(admin_mainDef::CFG_SHOW_WIDGET_DETAIL));
-		
 		// ウィジェットのタイプごとの処理
 		switch ($this->widgetType){
 			case '0':		// PC用テンプレート
@@ -493,33 +590,106 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 		if (!$this->isExistsWidgetList) $this->tmpl->setAttribute('widgetlist', 'visibility', 'hidden');// ウィジェットがないときは、一覧を表示しない
 		
 		// 画面にデータを埋め込む
-		$checkedStr = '';
-		if (!empty($this->showDetail)) $checkedStr = 'checked';
-		$this->tmpl->addVar("_widget", "show_detail", $checkedStr);		// 詳細表示
+		$showDetailValue = '0';
+		if (!empty($this->showDetail)) $showDetailValue = '1';
+		$this->tmpl->addVar("_widget", "show_detail", $showDetailValue);		// 詳細表示
 		$this->tmpl->addVar("show_dir", "install_dir", $installDir);// インストールディレクトリを設定
+		// 拡張表示アイコン
+		$imageUrl = $this->getUrl($this->gEnv->getRootUrl() . self::AREA_OPEN_ICON_FILE);
+		$imageTitle = '詳細表示';
+		$imageTag = '<img src="' . $imageUrl . '" width="32" height="32" border="0" alt="' . $imageTitle . '" title="' . $imageTitle . '" />';
+		$this->tmpl->addVar("_widget", "area_open_image", $imageTag);
+		// ウィジェットアップロード
+		$imageUrl = $this->getUrl($this->gEnv->getRootUrl() . self::UPLOAD_ICON_FILE);
+		$imageTitle = 'ウィジェットアップロード';
+		$imageTag = '<img src="' . $imageUrl . '" width="32" height="32" border="0" alt="' . $imageTitle . '" title="' . $imageTitle . '" />';
+		$this->tmpl->addVar("_widget", "upload_image", $imageTag);
+		// 再読み込みアイコン
+		$imageUrl = $this->getUrl($this->gEnv->getRootUrl() . self::RELOAD_ICON_FILE);
+		$imageTitle = 'ディレクトリ再読み込み';
+		$imageTag = '<img src="' . $imageUrl . '" width="32" height="32" border="0" alt="' . $imageTitle . '" title="' . $imageTitle . '" />';
+		$this->tmpl->addVar("show_dir", "reload_image", $imageTag);
 		
 		// テキストをローカライズ
 		$localeText = array();
+		$localeText['msg_get_new_info'] = $this->_('Get new information of widgets?');		// ウィジェットの最新情報を取得しますか?
 		$localeText['msg_update_line'] = $this->_('Update line?');		// 行を更新しますか?
 		$localeText['msg_delete_line'] = $this->_('Delete widget?');		// このウィジェットを削除しますか?
 		$localeText['msg_no_upload_file'] = $this->_('File not selected.');		// アップロードするファイルが選択されていません
 		$localeText['msg_upload_file'] = $this->_('Upload file.');		// ファイルをアップロードします
+		$localeText['msg_update_widget'] = $this->_('Update widget?');		// ウィジェットを更新しますか?
 		$localeText['label_widget_list'] = $this->_('Widget List');			// ウィジェット一覧
-		$localeText['label_widget_type'] = $this->_('Widget Type:');			// ウィジェットタイプ：
+//		$localeText['label_widget_type'] = $this->_('Widget Type:');			// ウィジェットタイプ：
 		$localeText['label_install_dir'] = $this->_('Install Directory:');			// インストールディレクトリ:
 		$localeText['label_read_new'] = $this->_('Reload directory');			// ディレクトリ再読み込み
-		$localeText['label_show_detail'] = $this->_('Show detail');			// 詳細表示
+//		$localeText['label_show_detail'] = $this->_('Show detail');			// 詳細表示
 		$localeText['label_widget_name'] = $this->_('Name');			// 名前
 		$localeText['label_widget_version'] = $this->_('Version');			// バージョン
+		$localeText['label_widget_latest_version'] = $this->_('Latest');			// 最新
 		$localeText['label_widget_available'] = $this->_('Available');			// 配置可
 		$localeText['label_widget_active'] = $this->_('Active');			// 実行可
 		$localeText['label_widget_date'] = $this->_('Release Date');			// リリース日
 		$localeText['label_widget_operation'] = $this->_('Operation');			// 操作
 		$localeText['label_widget_upload'] = $this->_('Widget Upload (zip compressed file)');			// ウィジェットアップロード(zip圧縮ファイル)
+		$localeText['msg_select_file'] = $this->_('Select file to upload.');			// アップロードするファイルを選択してください
 		$localeText['msg_replace_widget'] = $this->_('Replace widget if exists.');			// ウィジェットが存在する場合は置き換え
 		$localeText['label_upload'] = $this->_('Upload');			// アップロード
+		$localeText['label_cancel'] = $this->_('Cancel');			// キャンセル
 		$this->setLocaleText($localeText);
 	}
+	/**
+	 * ウィジェットバージョン更新コールバック関数
+	 *
+	 * @param array $matchData		検索マッチデータ
+	 * @return string				変換後データ
+	 */
+    function _update_widget_info_callback($matchData)
+	{
+		$this->db->updateWidgetVerInfo($matchData[1], $matchData[2]);
+		return $matchData[0];
+    }
+	/**
+	 * SQLクエリー文字列を解析して、パラメータを取得
+	 *
+	 * @param string $keys			キー文字列
+	 * @param string $values		値文字列
+	 * @return array				解析したパラメータの連想配列
+	 */
+    function _parseSqlQuery($keys, $values)
+	{
+		$updateParams = array();
+		
+		$keyArray = array_map('trim', explode(',', $keys));
+		$valueArray = explode(',', $values);
+		$valueArray = array_map(array($this, '_realValue'), $valueArray);
+		if (count($keyArray) == count($valueArray)){
+			$keyCount = count($keyArray);
+			for ($i = 0; $i < $keyCount; $i++){
+				$updateParams[$keyArray[$i]] = $valueArray[$i];
+			}
+		}
+		return $updateParams;
+	}
+	/**
+	 * SQLクエリー用の値の型を整える
+	 *
+	 * @param string $value			SQLクエリー文字列
+	 * @return						型変換した値
+	 */
+    function _realValue($value)
+	{
+		$value = trim($value);
+		if (strStartsWith($value, '\'') && strEndsWith($value, '\'')){			// 文字列
+			$value = trim($value, '\'');
+		} else {
+			if (strcasecmp($value, 'true') == 0){
+				$value = 1;
+			} else if (strcasecmp($value, 'false') == 0){
+				$value = 0;
+			}
+		}
+		return $value;
+	}
 	/**
 	 * ウィジェットのディレクトリの状態を取得
 	 *
@@ -629,6 +799,9 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function widgetListLoop($index, $fetchedRow, $param)
 	{
+		$version = $fetchedRow['wd_version'];
+		$latestVersion = $fetchedRow['wd_latest_version'];
+		
 		// ウィジェットが存在するかどうかチェック
 		$isExistsWidget = false;
 		$widgetId = $fetchedRow['wd_id'];// ウィジェットID
@@ -694,17 +867,47 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 		$idText = '<span ' . $helpText . '>' . $idText . '</span>';
 				
 		// ボタンの状態
-		$downloadButton = '';
-		if (!$isExistsWidget) $downloadButton = 'disabled';
-		if (!empty($fetchedRow['wd_license_type']))  $downloadButton = 'disabled';// ライセンスのチェック
+		$downloadDisabled = '';
+		if (!$isExistsWidget) $downloadDisabled = 'disabled';
+		if (!empty($fetchedRow['wd_license_type']))  $downloadDisabled = 'disabled';// ライセンスのチェック
 		
+		$downloadImg = $this->getUrl($this->gEnv->getRootUrl() . self::DOWNLOAD_ZIP_ICON_FILE);
+		if (empty($downloadDisabled)){
+			$downloadStr = 'ダウンロード';
+		} else {
+			$downloadStr = 'ダウンロード不可';
+		}
+		$downloadImage = '<img src="' . $downloadImg . '" width="32" height="32" border="0" alt="' . $downloadStr . '" title="' . $downloadStr . '" />';
+		
+		// 最新バージョンの表示
+		$latestVer = '';
+		$regex = '/([0-9\.]+)([a-z]*)/';
+		if (preg_match($regex, $latestVersion, $matches)){
+			if (version_compare($version, $latestVersion) == -1){		// 最新バージョンが現在のバージョンよりも上の場合のみ表示
+				$optionVerStr = strtolower($matches[2]);
+				if (empty($optionVerStr)){		// 付加記号なしの場合
+					$latestVer = '<span class="available"><a href="javascript:void(0);" onclick="updateWidget(\'' . $widgetId . '\');">' . $this->convertToDispString($latestVersion) . '</a></span>';
+				} else {
+					switch ($optionVerStr){
+						case 'x':		// 緊急バージョンアップ
+							$latestVer = '<span class="emergency"><a href="javascript:void(0);" onclick="updateWidget(\'' . $widgetId . '\');">' . 
+											$this->convertToDispString($latestVersion) . '</a></span>';
+							break;
+						default:		// ベータ版等
+							$latestVer = '<span>' . $this->convertToDispString($latestVersion) . '</span>';
+							break;
+					}
+				}
+			}
+		}
 		$row = array(
 			'no' => $index + 1,													// 行番号
 			'serial' => $this->convertToDispString($fetchedRow['wd_serial']),			// シリアル番号
 			'id' => $this->convertToDispString($widgetId),			// ID
 			'id_text' => $idText,
 			'name' => $this->convertToDispString($fetchedRow['wd_name']),		// 名前
-			'version' => $this->convertToDispString($fetchedRow['wd_version']),		// バージョン
+			'version' => $this->convertToDispString($version),		// バージョン
+			'latest_version' => $latestVer,		// 最新バージョン
 			'release_dt' => $this->convertToDispDate($fetchedRow['wd_release_dt']),	// リリース日時
 			'available' => $available,												// 利用可能かどうか
 			'active' => $active,													// ウィジェット実行可能かどうか
@@ -713,7 +916,8 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 			'update_button' => $buttonEnabled,									// 更新ボタンの使用制御
 			'delete_button' => $buttonEnabled,									// 削除ボタンの使用制御
 			'detail_button' => $detailButtonEnabled,							// 詳細ボタンの使用制御
-			'download_button' => $downloadButton,								// ダウンロードボタン
+			'download_image' => $downloadImage,								// ダウンロードボタンの画像
+			'download_disabled' => $downloadDisabled,								// ダウンロードボタンの使用可否
 			'image_tag' => $imageTag,		// 画像
 			'label_widget_config' => $this->_('Configure'),			// 設定
 			'label_update' => $this->_('Update'),			// 更新
