@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: chacha_mainDb.php 3348 2010-07-07 10:20:18Z fishbone $
+ * @version    SVN: $Id: chacha_mainDb.php 3364 2010-07-10 05:18:08Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -463,13 +463,17 @@ class chacha_mainDb extends BaseDb
 	 * @param int		$limit			取得する項目数
 	 * @param int		$page			取得するページ(1～)
 	 * @param function	$callback		コールバック関数
+	 * @param bool      $plusRecord		次のページ判断用に1レコード多く読み込むかどうか
 	 * @return 			なし
 	 */
-	function getThreadByMemberId($boardId, $memberId, $limit, $page, $callback)
+	function getThreadByMemberId($boardId, $memberId, $limit, $page, $callback, $plusRecord = false)
 	{
 		$offset = $limit * ($page -1);
 		if ($offset < 0) $offset = 0;
 		
+		// 次ページがあるか判断するために1レコード追加
+		if ($plusRecord) $limit++;
+		
 		$queryStr = 'SELECT * FROM mblog_thread LEFT JOIN mblog_thread_message ON mt_board_id = mm_board_id AND mt_id = mm_thread_id AND mm_deleted = false AND mm_index = 1 ';
 		$queryStr .=  'WHERE mt_board_id = ? ';
 		$queryStr .=    'AND mt_deleted = false ';		// 削除されていない
